@@ -7,10 +7,8 @@ use Cwd qw/realpath/;
 use File::Basename qw/basename dirname/;
 use File::Spec ();
 
-use vars qw/$VERSION/;
-$VERSION = '1.2';
-use vars qw/@ISA/;
-@ISA = qw/DynaLoader/;
+our $VERSION = '1.3';
+our @ISA = qw/DynaLoader/;
 
 bootstrap RPM2 $VERSION;
 
@@ -99,7 +97,7 @@ sub create_transaction
 
 package RPM2::DB;
 
-$VERSION = $RPM2::VERSION;
+our $VERSION = $RPM2::VERSION;
 
 sub find_all_iter {
   my $self = shift;
@@ -169,7 +167,7 @@ sub find_by_file {
 
 package RPM2::Header;
 
-$VERSION = $RPM2::VERSION;
+our $VERSION = $RPM2::VERSION;
 
 use overload '<=>'  => \&op_spaceship,
              'cmp'  => \&op_spaceship,
@@ -331,7 +329,7 @@ sub changelog {
 
 package RPM2::PackageIterator;
 
-$VERSION = $RPM2::VERSION;
+our $VERSION = $RPM2::VERSION;
 
 sub new_iterator {
   my $class = shift;
@@ -379,7 +377,7 @@ sub DESTROY {
 
 package RPM2::Transaction;
 
-$VERSION = $RPM2::VERSION;
+our $VERSION = $RPM2::VERSION;
 
 sub _new_raw {
   my $class         = shift;
